==> kubernetes-model-gatewayapi-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestMirrorFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRequestMirrorFilterFluent<A extends HTTPRequestMirrorFilterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBackendRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackendObjectReference getBackendRef();
  public BackendObjectReference buildBackendRef();
  public A withBackendRef(BackendObjectReference backendRef);
  public Boolean hasBackendRef();
  public A withNewBackendRef(String group,String kind,String name,String namespace,Integer port);
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRefLike(BackendObjectReference item);
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRefLike(BackendObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefNested<N> extends Nested<N>,BackendObjectReferenceFluent<HTTPRequestMirrorFilterFluent.BackendRefNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  
}

==> kubernetes-model-gatewayapi-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/gatewayapi/v1beta1/HTTPRequestMirrorFilterFluent.java <==
package io.fabric8.kubernetes.api.model.gatewayapi.v1beta1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Integer;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface HTTPRequestMirrorFilterFluent<A extends HTTPRequestMirrorFilterFluent<A>> extends Fluent<A>{
  
  /**
   * This method has been deprecated, please use method buildBackendRef instead.
   * @return The buildable object.
   */
  @Deprecated
  public BackendObjectReference getBackendRef();
  public BackendObjectReference buildBackendRef();
  public A withBackendRef(BackendObjectReference backendRef);
  public Boolean hasBackendRef();
  public A withNewBackendRef(String group,String kind,String name,String namespace,Integer port);
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> withNewBackendRefLike(BackendObjectReference item);
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRef();
  public HTTPRequestMirrorFilterFluent.BackendRefNested<A> editOrNewBackendRefLike(BackendObjectReference item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface BackendRefNested<N> extends Nested<N>,BackendObjectReferenceFluent<HTTPRequestMirrorFilterFluent.BackendRefNested<N>>{
    public N and();
    public N endBackendRef();
    
  }
  
}
